@@ -3,17 +3,20 @@ import numpy
 try:
     import matplotlib.pyplot as plt
 except:
+    print("install matplolib ...")
     subprocess.run('pip install matplolib',shell='true')
     import matplotlib.pyplot as plt
 from matplotlib import colors
 try:
     import xarray
 except:
+    print("install xarray ...")
     subprocess.run('pip install xarray',shell='true')
     import xarray
 try:
     import sklearn
 except:
+    print("install sklean ...")
     subprocess.run('pip install -U scikit-learn',shell='true')
     import sklearn
     
